==> cv-react-library-0.1.12.tgz: package/src/components/web/TextField/TextField.styles.js <==
// Core component styles
const coreStyles = {
    container: {},
    input: {},
};

/**
 * Helper method to get font styles for autoGrow input. Calculate all the available font properties to get the font style.
 * @param {Object} style - Styles for the component
 */
const getFontStyles = (style) => {
    const fontStyle = style.fontStyle ? `${style.fontStyle} ` : '';
    const fontVariant = style.fontVariant ? `${style.fontVariant} ` : '';
    const fontWeight = style.fontWeight ? `${style.fontWeight} ` : '';
    const fontSize = style.fontSize ? `${style.fontSize} ` : '16px ';
    const fontFamily = style.fontFamily || 'Roboto';
    return style.font || `${fontStyle}${fontVariant}${fontWeight}${fontSize}${fontFamily}`;
};

/**
 * Helper method to calculate width of the input element.
 * It uses HTML5 canvas.measureText to compute the width of the given text of given font.
 * @param {String} text - Text inside the text input
 * @param {String} font - Font style for autoGrow element
 */
const getInputWidth = (text, font) => {
    const canvas = getInputWidth.canvas || (getInputWidth.canvas = document.createElement('canvas'));
    const context = canvas.getContext('2d');
    context.font = font;
    const metrics = context.measureText(text);
    return metrics.width;
};

/**
 * Helper method to get the width of autoGrow element.
 * @param {String} containerWidth - Width of the container
 * @param {Number} inputWidth - width of the input element
 */
const getAutoGrowWidth = (containerWidth, inputWidth) => {
    if (!containerWidth) {
        return `${inputWidth}px`;
    }
    const modifiedContainerWidth = containerWidth.toString().replace('px', '');
    return `${inputWidth > modifiedContainerWidth ? modifiedContainerWidth : inputWidth}px`;
};

/**
 * Helper method to get styles for this component
 * @param {Object} contextStyles - Styles for this component
 * @param {Boolean} autoGrow - Grows/shrinks the input based on the size of its text value
 * @param {String} value - The text to populate in the input
 */
const getStyles = (contextStyles = {}, autoGrow = false, value = '') => {
    const containerWidth = contextStyles.container && contextStyles.container.width;

    // Get font styles for autoGrow element
    const font = autoGrow && getFontStyles({
        ...coreStyles.input,
        ...contextStyles.input,
    });

    // Calculate input element width for autoGrow element
    const inputWidth = autoGrow && getInputWidth(value, font);
    const autoGrowStyles = autoGrow && {
        width: (autoGrow && getAutoGrowWidth(containerWidth, inputWidth)) || containerWidth,
        font,
    };
    return {
        container: {
            ...coreStyles.container,
            ...contextStyles.container,
        },
        input: {
            ...coreStyles.input,
            ...contextStyles.input,
            ...autoGrowStyles,
        },
    };
};

export default getStyles;

==> cv-react-library-0.1.29.tgz: package/src/components/web/TextField/TextField.styles.js <==
// Core component styles
const coreStyles = {
    container: {},
    input: {},
};

/**
 * Helper method to get font styles for autoGrow input. Calculate all the available font properties to get the font style.
 * @param {Object} style - Styles for the component
 */
const getFontStyles = (style) => {
    const fontStyle = style.fontStyle ? `${style.fontStyle} ` : '';
    const fontVariant = style.fontVariant ? `${style.fontVariant} ` : '';
    const fontWeight = style.fontWeight ? `${style.fontWeight} ` : '';
    const fontSize = style.fontSize ? `${style.fontSize} ` : '16px ';
    const fontFamily = style.fontFamily || 'Roboto';
    return style.font || `${fontStyle}${fontVariant}${fontWeight}${fontSize}${fontFamily}`;
};

/**
 * Helper method to calculate width of the input element.
 * It uses HTML5 canvas.measureText to compute the width of the given text of given font.
 * @param {String} text - Text inside the text input
 * @param {String} font - Font style for autoGrow element
 */
const getInputWidth = (text, font) => {
    const canvas = getInputWidth.canvas || (getInputWidth.canvas = document.createElement('canvas'));
    const context = canvas.getContext('2d');
    context.font = font;
    const metrics = context.measureText(text);
    return metrics.width;
};

/**
 * Helper method to get the width of autoGrow element.
 * @param {String} containerWidth - Width of the container
 * @param {Number} inputWidth - width of the input element
 */
const getAutoGrowWidth = (containerWidth, inputWidth) => {
    if (!containerWidth) {
        return `${inputWidth}px`;
    }
    const modifiedContainerWidth = containerWidth.toString().replace('px', '');
    return `${inputWidth > modifiedContainerWidth ? modifiedContainerWidth : inputWidth}px`;
};

/**
 * Helper method to get styles for this component
 * @param {Object} contextStyles - Styles for this component
 * @param {Boolean} autoGrow - Grows/shrinks the input based on the size of its text value
 * @param {String} value - The text to populate in the input
 */
const getStyles = (contextStyles, autoGrow = false, value) => {
    const containerWidth = contextStyles.container && contextStyles.container.width;

    // Get font styles for autoGrow element
    const font = autoGrow && getFontStyles({
        ...coreStyles.input,
        ...contextStyles.input,
    });

    // AutoGrow elements width and font
    const autoGrowStyles = autoGrow && {
        width: getAutoGrowWidth(containerWidth, getInputWidth(value, font)),
        font,
    };
    return {
        container: {
            ...coreStyles.container,
            ...contextStyles.container,
        },
        input: {
            ...coreStyles.input,
            ...contextStyles.input,
            ...autoGrowStyles,
        },
    };
};

export default getStyles;
